Index: webrtc/config.h |
diff --git a/webrtc/config.h b/webrtc/config.h |
index 0231cb56827500331329a8d4e6a5ecd2e3e0abfc..a6778715d87f634692a63b59aac64d3010ec73c6 100644 |
--- a/webrtc/config.h |
+++ b/webrtc/config.h |
@@ -35,10 +35,10 @@ struct NackConfig { |
int rtp_history_ms; |
}; |
-// Settings for forward error correction, see RFC 5109 for details. Set the |
-// payload types to '-1' to disable. |
-struct FecConfig { |
- FecConfig() |
+// Settings for ULPFEC forward error correction. |
+// Set the payload types to '-1' to disable. |
+struct UlpfecConfig { |
+ UlpfecConfig() |
: ulpfec_payload_type(-1), |
red_payload_type(-1), |
red_rtx_payload_type(-1) {} |